#

# spec file for package rhnlib
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2008-2018 Red Hat, Inc.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%if 0%{?fedora} || 0%{?suse_version} > 1320 || 0%{?rhel} >= 8
%global build_py3   1
%{!?__python3:%global __python3 /usr/bin/python3}

%if %{undefined python3_sitelib}
%global python3_sitelib %(%{__python3} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")
%endif
%endif

%if !(0%{?rhel} >= 8 || 0%{?sle_version} >= 150400 )
%global build_py2   1
%{!?__python2:%global __python2 /usr/bin/python2}
%if %{undefined python2_sitelib}
%global python2_sitelib %(%{__python2} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")
%endif
%endif


%if "%{_vendor}" == "debbuild"
# For making sure we can set the right args for deb distros
%global is_deb 1
%endif


Summary:        Python libraries for the Spacewalk project
License:        GPL-2.0-only
Name:           rhnlib
Version:        4.2.5
Release:    3.31.1
%if "%{_vendor}" == "debbuild"
Group:      python
Packager:   Uyuni Project <uyuni-devel@opensuse.org>
%else
Group:      Development/Libraries
%endif
Url:            https://github.com/uyuni-project/uyuni
Source0: rhnlib-git-0.0b05506.tar.gz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if 0%{?fedora} || 0%{?rhel} || 0%{?suse_version} >= 1210
BuildArch:      noarch
%endif

%description
rhnlib is a collection of python modules used by the Spacewalk (http://spacewalk.redhat.com) software.

%if 0%{?build_py2}
%package -n python2-rhnlib
Summary:        Python libraries for the Spacewalk project
Group:          Development/Libraries

%if "%{_vendor}" != "debbuild"
%if 0%{?fedora} >= 28 || 0%{?rhel} >= 8
BuildRequires:  python2-devel
Requires:       python2-pyOpenSSL
%else
BuildRequires:  python-devel
%if 0%{?suse_version}
%if 0%{?suse_version} > 1200
Requires:       python-pyOpenSSL
%else
Requires:       python-openssl
Requires:       python-backports.ssl_match_hostname
%endif # 0{?suse_version} > 1200
%else
Requires:       pyOpenSSL
%endif # 0{?suse_version}
%endif # 0{?fedora} >= 28 || 0{?rhel} >= 8
%endif # {_vendor} != "debbuild"

%if "%{_vendor}" == "debbuild"
BuildRequires: python-dev
BuildRequires: rpm
Requires(preun): python-minimal
Requires(post): python-minimal
Requires: python-openssl
Obsoletes: python-rhn
Conflicts: python-rhn
%endif

Conflicts:      rhncfg < 5.10.45
Conflicts:      spacewalk-proxy-installer < 1.3.2
Conflicts:      rhn-client-tools < 1.3.3
Conflicts:      rhn-custom-info < 5.4.7
Conflicts:      rhnpush < 5.5.10
Conflicts:      rhnclient < 0.10
Conflicts:      spacewalk-proxy < 1.3.6

Provides:       rhnlib = %{version}-%{release}
Obsoletes:      rhnlib < %{version}-%{release}

%description -n python2-rhnlib
rhnlib is a collection of python modules used by the Spacewalk software.

%endif # 0%{?build_py2}

%if 0%{?build_py3}
%package -n python3-rhnlib
Summary:        Python libraries for the Spacewalk project

%if "%{_vendor}" != "debbuild"
BuildRequires:  python3-devel
%if 0%{?suse_version}
BuildRequires:  python-rpm-macros
%endif
%endif
Requires:       python3-pyOpenSSL

%if "%{_vendor}" == "debbuild"
BuildRequires: python3-dev
BuildRequires: rpm
Requires(preun): python3-minimal
Requires(post): python3-minimal
Requires: python3-openssl
%endif

Conflicts:      rhncfg < 5.10.45
Conflicts:      spacewalk-proxy-installer < 1.3.2
Conflicts:      rhn-client-tools < 1.3.3
Conflicts:      rhn-custom-info < 5.4.7
Conflicts:      rhnpush < 5.5.10
Conflicts:      rhnclient < 0.10
Conflicts:      spacewalk-proxy < 1.3.6

%description -n python3-rhnlib
rhnlib is a collection of python modules used by the Spacewalk software.

%endif # 0%{?build_py2}

%prep
%setup -q -n rhnlib-git-0.0b05506

if [ ! -e setup.py ]; then
    sed -e 's/@VERSION@/%{version}/' -e 's/@NAME@/%{name}/' setup.py.in > setup.py
fi
if [ ! -e setup.cfg ]; then
    sed 's/@RELEASE@/%{release}/' setup.cfg.in > setup.cfg
fi


%build
%if 0%{?build_py2}
make -f Makefile.rhnlib PYTHON=%{__python2}
%endif
%if 0%{?build_py3}
make -f Makefile.rhnlib PYTHON=%{__python3}
%endif


%install
%if 0%{?build_py2}
%{__python2} setup.py install %{!?is_deb:-O1}%{?is_deb:--no-compile -O0} --skip-build --root $RPM_BUILD_ROOT %{?is_deb:--install-layout=deb} --prefix=%{_prefix}
%endif
%if 0%{?build_py3}
%{__python3} setup.py install %{!?is_deb:-O1}%{?is_deb:--no-compile -O0} --skip-build --root $RPM_BUILD_ROOT %{?is_deb:--install-layout=deb} --prefix=%{_prefix}
%endif

%if 0%{?build_py2}
%files -n python2-rhnlib
%defattr(-,root,root)
%doc ChangeLog COPYING README TODO
%{python2_sitelib}/*
%endif

%if 0%{?build_py3}
%files -n python3-rhnlib
%doc ChangeLog COPYING README TODO
%{python3_sitelib}/*
%endif

%if "%{_vendor}" == "debbuild"

%post -n python2-rhnlib
# Do late-stage bytecompilation, per debian policy
pycompile -p python2-rhnlib -V -3.0

%preun -n python2-rhnlib
# Ensure all *.py[co] files are deleted, per debian policy
pyclean -p python2-rhnlib

%if 0%{?build_py3}
%post -n python3-rhnlib
# Do late-stage bytecompilation, per debian policy
py3compile -p python3-rhnlib -V -4.0

%preun -n python3-rhnlib
# Ensure all *.py[co] files are deleted, per debian policy
py3clean -p python3-rhnlib
%endif
%endif

%changelog
* Wed Feb  2 2022 jmassaguerpla@suse.de
- version 4.2.5-1
  * do not build python 2 package for SLE15
* Fri Jul 16 2021 jgonzalez@suse.com
- version 4.2.4-1
- Adapt the tests to the new images
* Fri Apr 16 2021 jgonzalez@suse.com
- version 4.2.3-1
- require missing python-backports.ssl_match_hostname on SLE 11 (bsc#1183959)
* Wed Feb 17 2021 jgonzalez@suse.com
- version 4.2.2-1
- change SSL implementation to python ssl for better SAN and
  hostname matching support (bsc#1181807)
* Fri Sep 18 2020 jgonzalez@suse.com
- version 4.2.1-1
- Update package version to 4.2.0
* Wed Mar 11 2020 jgonzalez@suse.com
- version 4.1.2-1
- Fix building
* Wed Nov 27 2019 jgonzalez@suse.com
- version 4.1.1-1
- Fix malformed XML response when data contains non-ASCII chars (bsc#1154968)
- Bump version to 4.1.0 (bsc#1154940)
- fix initialize ssl connection (bsc#1144155)
- Add SNI support for clients
- Fix bootstrapping SLE11SP4 trad client with SSL enabled (bsc#1148177)
* Wed May 15 2019 jgonzalez@suse.com
- version 4.0.8-1
- SPEC cleanup
* Mon Apr 22 2019 jgonzalez@suse.com
- version 4.0.7-1
- Add makefile and pylint configuration for PyLint
* Fri Mar 29 2019 jgonzalez@suse.com
- version 4.0.6-1
- Add group to python*-rhnlib to fix building at SLE11
* Sat Mar  2 2019 jgonzalez@suse.com
- version 4.0.5-1
- Read SSL decoded buffer completely when no pending bytes on the
  underlying connection.
* Wed Feb 27 2019 jgonzalez@suse.com
- version 4.0.4-1
- Fix encoding issues after porting to Python 3.
* Thu Jan 31 2019 jgonzalez@suse.com
- version 4.0.3-1
- Sync changes from Spacewalk
- 1652859 - python3 http.client does not contain _set_hostport()
* Fri Oct 26 2018 jgonzalez@suse.com
- version 4.0.2-1
- use rpm for debian packaging
* Fri Aug 10 2018 jgonzalez@suse.com
- version 4.0.1-1
- Bump version to 4.0.0 (bsc#1104034)
- Fix copyright for the package specfile (bsc#1103696)
* Mon May  7 2018 jgonzalez@suse.com
- version 2.8.11.1-1
- Sync with upstream (bsc#1083294)
* Mon Mar 26 2018 jgonzalez@suse.com
- version 2.8.10.1-1
- Sync with upstream (bsc#1083294)
* Mon Mar  5 2018 jgonzalez@suse.com
- version 2.8.7.2-1
- remove empty clean section from spec (bsc#1083294)
* Fri Feb 23 2018 jgonzalez@suse.com
- version 2.8.7.1-1
- Sync with upstream
* Fri Feb  2 2018 jgonzalez@suse.com
- version 2.8.5.3-1
- replace netstat with ss command
* Wed Jan 17 2018 jgonzalez@suse.com
- version 2.8.5.2-1
- Fix update mechanism when updating the updateservice (bsc#1073619)
* Fri Nov 10 2017 mc@suse.de
- version 2.8.5.1-1
- merge back upstream changes
* Thu Oct 26 2017 mc@suse.de
- version 2.8.4.1-1
- build python3 package
- check a state of handshake before shutdown SSL connection
- Python's OpenSSL.SSL.Connection method for getting state was renamed.
* Wed May  3 2017 michele.bologna@suse.com
- version 2.7.2.1-1
* Fri Mar 31 2017 mc@suse.de
- version 2.7.1.3-1
- support all TLS versions in rpclib (bsc#1025312)
* Mon Mar  6 2017 mc@suse.de
- version 2.7.1.2-1
- Updated links to github in spec files
* Wed Jan 11 2017 michele.bologna@suse.com
- version 2.7.1.1-1
- Version 2.7.1-1
* Thu Oct  6 2016 mc@suse.de
- version 2.5.84.3-1
- Add function aliases for backward compatibility (bsc#998185)
* Mon Mar 21 2016 mc@suse.de
- version 2.5.84.2-1
- use TLSv1_METHOD in SSL Context (bsc#970989)
* Wed Mar  2 2016 mc@suse.de
- version 2.5.84.1-1
- just set one required attribute to be compatible with all
  xmlrpclib versions
- fixed SyntaxError: invalid syntax ' .. = b ' to work in
  python 2.4
* Tue Jan 26 2016 mc@suse.de
- version 2.5.83.1-1
- change encoding for python 2
- os.write wants buffer
- xmlrpc can't convert map objects
- dict.iteritems() is not in python3
- perform decoding on byte string
- modified exception raising to work in python2/3
- fixed string module calls to work in python3
* Sat Jan 16 2016 mc@suse.de
- version 2.5.81.1-1
- make rhnlib compatible with python 2 and 3
* Mon Nov 30 2015 mc@suse.de
- version 2.5.77.2-1
- python 2.7 httplib changed function _set_hostport to _get_hostport
* Wed Oct  7 2015 mc@suse.de
- version 2.5.77.1-1
- python 3 compatibility
- SmartIO: don't use tmpDir configuration from /etc/sysconfig/rhn/up2date
* Tue Mar 31 2015 mc@suse.de
- version 2.5.69.7-1
- Documentation changes - fix name and refer to RFC.
* Tue Feb  3 2015 mc@suse.de
- version 2.5.69.6-1
- Getting rid of Tabs and trailing spaces
* Thu Dec 18 2014 mc@suse.de
- version 2.5.69.5-1
* Wed Sep  3 2014 ro@suse.de
- sanitize release line in specfile
* Tue Jun 17 2014 jrenner@suse.de
- version 2.5.69.4-1
- Ensure bytes strings are sent to pyOpenSSL (bnc#880388)
* Thu Apr 10 2014 mc@suse.de
- version 2.5.69.3-1
* Thu Apr 10 2014 mc@suse.de
- fix release in specfile for SLE12 (bnc#872970)
* Mon Jan 20 2014 mc@suse.de
- version 2.5.69.2-1
- change license to SPDX format
* Mon Dec  9 2013 mc@suse.de
- version 2.5.69.1-1
- switch to 2.1
* Thu Nov 28 2013 mc@suse.de
- version 2.5.51.6-1
- fixed UserDictCase behaviour when key is not found
* Wed Aug 21 2013 mc@suse.de
- version 2.5.51.5-1
- timeout fixes
* Mon Apr 22 2013 mc@suse.de
- version 2.5.51.4-1
- Make timeout of yum-rhn-plugin calls through rhn-client-tools
  configurable (bnc#815460)
- make Proxy timeouts configurable (bnc#815460)
* Thu Jun 21 2012 jrenner@suse.de
- version 2.5.51.3-1
- allow linking against openssl
* Fri Apr 27 2012 mc@suse.de
- version 2.5.51.2-1
- fixing typos
* Wed Mar 21 2012 mc@suse.de
- version 2.5.51.1-1
- Bumping package version
* Mon Sep 19 2011 mc@suse.de
- require python-openssl on SUSE
* Sat Jan 22 2011 mc@suse.de
- fix macros
* Tue Sep 14 2010 mantel@suse.de
- Initial release of rhnlib
